"""Default package."""

__author__ = "Robert Kaussow"
__project__ = "ansible-later"
__license__ = "MIT"
__maintainer__ = "Robert Kaussow"
__email__ = "mail@thegeeklab.de"
__url__ = "https://github.com/xoxys/ansible-later"
__version__ = "0.3.9"

from ansiblelater import logger

LOG = logger.get_logger("ansiblelater")
